@@ -25,7 +25,7 @@ try:
     exec("\n".join(code))
     match.run()
 except Exception as e:
-    debug_message = e
+    debug_message = str(e)
     code_successful = False
 
 result_file_name = sys.argv[3]
